#!/usr/bin/python3

import os
import subprocess
import sys

sys.dont_write_bytecode = True
from flaky_tests_list import flaky_test_dirs

cwd = os.getcwd()

overall_test_rc = 0
succeeded_tests = []
failed_tests = []

for i in flaky_test_dirs:

    os.chdir(i)

    print ("\n\n", flush=True)
    print ("############################################################", flush=True)
    print ("############################################################", flush=True)
    print ("#### Running FLAKY tests in", i, flush=True)
    print ("############################################################", flush=True)
    print ("############################################################", flush=True)

    rc = subprocess.run([
        '/usr/bin/ansible-test',
        'units',
        '--python-interpreter',
        '/usr/bin/python3',
        '--local'
    ])

    # don't fail on failed test, continue instead
    print ("## return code is", rc.returncode)

    if rc.returncode == 0:
        succeeded_tests.append(i)
    else:
        failed_tests.append(i)
        overall_test_rc = rc.returncode

    os.chdir(cwd)

print ("############################################################", flush=True)
print ("############################################################", flush=True)
print ("#### failed tests are:", flush=True)
for i in failed_tests:
    print ("####", i, flush=True)
if len(succeeded_tests) > 0:
    print ("#### succeeded tests are:", flush=True)
    for i in succeeded_tests:
        print ("####", i, flush=True)
    print ("#### consider removing them from the flaky tests list.", flush=True)
print ("############################################################", flush=True)
print ("############################################################", flush=True)


exit(overall_test_rc)



#!/usr/bin/python3

import glob
import os
import subprocess
import sys

sys.dont_write_bytecode = True
from flaky_tests_list import flaky_test_dirs

cwd = os.getcwd()

overall_test_rc = 0
failed_tests = []

# find all dirs that have unit tests
for i in glob.glob('ansible_collections/**/tests/unit', recursive=True):

    # base path to run ansible-test is two levels up
    testdir = os.path.normpath(
        os.path.join(i, '..', '..')
    )

    # skip any tests that are flagged as flaky
    if testdir in flaky_test_dirs:
        print("Skipping", testdir)
        continue

    os.chdir(testdir)

    print ("\n\n", flush=True)
    print ("############################################################", flush=True)
    print ("############################################################", flush=True)
    print ("#### Running tests in", testdir, flush=True)
    print ("############################################################", flush=True)
    print ("############################################################", flush=True)

    rc = subprocess.run([
        '/usr/bin/ansible-test',
        'units',
        '--python-interpreter',
        '/usr/bin/python3',
        '--local'
    ])


    if rc.returncode != 0:
        failed_tests.append(i)
        overall_test_rc = rc.returncode

    os.chdir(cwd)


if overall_test_rc != 0:
    print ("############################################################", flush=True)
    print ("############################################################", flush=True)
    print ("#### failed tests are:", flush=True)
    for i in failed_tests:
        print ("####", i, flush=True)
    print ("############################################################", flush=True)
    print ("############################################################", flush=True)

exit(overall_test_rc)



#!/usr/bin/python3

# check if the list of flaky tests is actually valid
# Must be run from base of git dir

import os
import subprocess
import sys

sys.dont_write_bytecode = True
from flaky_tests_list import flaky_test_dirs

rc = 0

for i in flaky_test_dirs:

    testdir = os.path.join(i, 'tests', 'unit')

    if not os.path.isdir(testdir):
        print(testdir, 'does not exist. Consider removing it from flaky_test_dirs.py')
        rc=1

exit(rc)



#!/usr/bin/python3

# This is a list of unit tests that currently fail for various reasons.
# This list is skipped in unit-tests-stable.py
# This list is run in unit-tests-flaky.py

flaky_test_dirs = [
    'ansible_collections/amazon/aws',
    'ansible_collections/ansible/netcommon',
    'ansible_collections/ansible/utils',                    # tests matches broken; waiting for upstream fix
    'ansible_collections/cisco/aci',                        # Test likely needs updating; lxml error message on invalid parse changed.
    'ansible_collections/cisco/dnac',                        # TypeError: TestDnacDiscoveryIntent.__init__() takes 1 positional argument but 2 were given
    'ansible_collections/community/aws',
    'ansible_collections/community/ciscosmb',
    'ansible_collections/community/digitalocean',
    'ansible_collections/community/dns',                    # [1]
    'ansible_collections/community/docker',
    'ansible_collections/community/general',                # import broken
    'ansible_collections/community/hrobot',                 # import broken
    'ansible_collections/community/library_inventory_filtering_v1', # [1]
    'ansible_collections/community/proxmox',
    'ansible_collections/community/routeros',
    'ansible_collections/community/sap_libs',
    'ansible_collections/dellemc/enterprise_sonic',
    'ansible_collections/dellemc/openmanage',
    'ansible_collections/ibm/storage_virtualize',
    'ansible_collections/infoblox/nios_modules',            # All tests failing with "RuntimeError: Patch is already started"
    'ansible_collections/junipernetworks/junos',            # test broken
    'ansible_collections/kubernetes/core',
    'ansible_collections/netapp/cloudmanager',
    'ansible_collections/netapp_eseries/santricity',        # [0]
    'ansible_collections/netapp/ontap',                     # missing netapp_lib
    'ansible_collections/netapp/storagegrid',
    'ansible_collections/ngine_io/cloudstack',              # [0]
    'ansible_collections/ravendb/ravendb',                 # doesn't ship ravendb_test_driver
    'ansible_collections/splunk/es',                        # assert result["changed"] is True
    'ansible_collections/vmware/vmware',                    # depends on libs not packaged in Debian
    'ansible_collections/vultr/cloud',
]

# [0] test/units/compat/mock.py from ansible-core source is not installed
#     in the binary package. Need to check why.
# [1] E   ModuleNotFoundError: No module named 'ansible_collections.community.internal_test_tools'
